#define lMotor 6 // these are connection pin numbers
#define rMotor 5
#define xMotor 7
#define yMotor 8
#define lAdjust 10 // adjust these if servos are off center
#define rAdjust 10
#define xAdjust 10
#define yAdjust 10
#define servoMinPeriod 5 // The shortest allowable time since last servo update
#define servoEnable // disable me if you don't want the robot to move
int timeSince;
int lastUpdate;

void servoReady()
{
  pinMode(lMotor, OUTPUT);
  pinMode(rMotor, OUTPUT);
  digitalWrite(lMotor, LOW);
  digitalWrite(rMotor, LOW);
  pinMode(xMotor, OUTPUT);
  pinMode(yMotor, OUTPUT);
  digitalWrite(xMotor, LOW);
  digitalWrite(yMotor, LOW);
  lastUpdate = 0;
  timeSince = 0;
}

void servoUpdateDrive(unsigned int lSpeed, unsigned int rSpeed)
{
  lSpeed = lSpeed - 10 + lAdjust; // adjustment, see definitions above
  rSpeed = rSpeed - 10 + rAdjust;

  // this step will wait for 5ms no matter what
  timeSince = millis() - lastUpdate;
  if (timeSince < servoMinPeriod)
  {
    delay(servoMinPeriod - timeSince);
  }

  if((lSpeed < 1490) || (lSpeed > 1510))
  {
    // send pulses to servos
#ifdef servoEnable
    digitalWrite(lMotor, HIGH);
#endif
    delayMicroseconds(lSpeed);
    digitalWrite(lMotor, LOW);
  } 
  else {
    delay(2);
  }

  if((rSpeed < 1490) || (rSpeed > 1510))
  {
#ifdef servoEnable
    digitalWrite(rMotor, HIGH);
#endif
    delayMicroseconds(rSpeed);
    digitalWrite(rMotor, LOW);
  } 
  else {
    delay(2);
  }

  lastUpdate = millis();
}

void servoUpdateHead(unsigned int xPos, unsigned int yPos)
{
  xPos = xPos - 10 + xAdjust;
  yPos = yPos - 10 + yAdjust;

  timeSince = millis() - lastUpdate;
  if (timeSince < servoMinPeriod)
  {
    delay(servoMinPeriod - timeSince);
  }

#ifdef servoEnable
  digitalWrite(xMotor, HIGH);
#endif
  delayMicroseconds(xPos);
  digitalWrite(xMotor, LOW);

#ifdef servoEnable
  digitalWrite(yMotor, HIGH);
#endif
  delayMicroseconds(yPos);
  digitalWrite(yMotor, LOW);

  lastUpdate = millis();
}
